| Title: | Connects to Google Cloud API for Label Detection |
|---|---|
| Description: | Connects to Google cloud vision <https://cloud.google.com/vision> to perform label detection and repurpose this feature for image classification. |
| Authors: | Mohamed Soudy [aut, cre], Yasmine Afify [aut], Nagwa Badr [aut] |
| Maintainer: | Mohamed Soudy <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-05-12 05:57:58 UTC |
| Source: | https://github.com/mohmedsoudy/ortsc |
This function can be used to authenticate users
authenticate(googleAuthR.client_id, googleAuthR.client_secret)authenticate(googleAuthR.client_id, googleAuthR.client_secret)
googleAuthR.client_id |
Client id provided by Google API cloud service |
googleAuthR.client_secret |
Client secret provided by Google API cloud service |
a vector of objects
Mohmed Soudy [email protected], Yasmine Afify [email protected], and Nagwa Badr [email protected]
A dataset containing the objects and its In-door and Out-door weights. The variables are as follows:
data(ClassLogic)data(ClassLogic)
A data frame with 20 rows and 3 variables
Object. object name
Class. class of data (Indoor, Outdoor)
Weight. Classification weight (0–1)
This function can be used to classify image based on objects detected
GetLabels(ImagePaths)GetLabels(ImagePaths)
ImagePaths |
vector of complete image's paths |
a vector of objects
Mohmed Soudy [email protected], Yasmine Afify [email protected], and Nagwa Badr [email protected]