Welcome to ClientVPS Mirrors

Help for package ORTSC
Title: Connects to Google Cloud API for Label Detection
Version: 1.0.0
Author: Mohamed Soudy [aut, cre], Yasmine Afify [aut], Nagwa Badr [aut]
Maintainer: Mohamed Soudy <MohmedSoudy2009@gmail.com>
Description: Connects to Google cloud vision https://cloud.google.com/vision to perform label detection and repurpose this feature for image classification.
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Imports: utils , stats, googleAuthR, googleCloudVisionR
URL: https://github.com/MohmedSoudy/ORTSC
BugReports: https://github.com/MohmedSoudy/ORTSC/issues
NeedsCompilation: no
Packaged: 2021-02-06 16:08:34 UTC; RSH
Repository: CRAN
Date/Publication: 2021-02-10 16:30:07 UTC

Connects to Google Cloud API label detection and perform multiple object detection

Description

This function can be used to classify image based on objects detected

Usage

GetLabels(ImagePaths)

Arguments

ImagePaths

vector of complete image's paths

Value

a vector of objects

Author(s)

Mohmed Soudy Mohamed.soudy@57357.com, Yasmine Afify yasmine.afify@cis.asu.edu.eg, and Nagwa Badr Nagwabadr@cis.asu.edu.eg

Examples

## Not run: 
 GetLabels(https://cloud.google.com/vision/docs/images/crop_both.jpeg)

## End(Not run)


Connects to Google Cloud API for user-authentication

Description

This function can be used to authenticate users

Usage

authenticate(googleAuthR.client_id, googleAuthR.client_secret)

Arguments

googleAuthR.client_id

Client id provided by Google API cloud service

googleAuthR.client_secret

Client secret provided by Google API cloud service

Value

a vector of objects

Author(s)

Mohmed Soudy Mohamed.soudy@57357.com, Yasmine Afify yasmine.afify@cis.asu.edu.eg, and Nagwa Badr Nagwabadr@cis.asu.edu.eg

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.